@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-compat
-version: 0.3.0.0
-id: aeson-compat-0.3.0.0-a20a161a51c55c8ab6017f045ab6c3e9
-key: aeson_G4kDUECtpuKJHDAeY6OyCk
+version: 0.3.1.0
+id: aeson-compat-0.3.1.0-87477b046d7b864555f128ca536b6538
+key: aeson_0S7OUK4gqfF6axxSUneNAN
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/aeson-compat#readme
@@ -17,12 +17,12 @@ exposed-modules:
     Data.Aeson.Compat
 hidden-modules: Data.Aeson.Compat.Time
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.0.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.0.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.0.0
-hs-libraries: HSaeson-compat-0.3.0.0-G4kDUECtpuKJHDAeY6OyCk
+import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.1.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.1.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.1.0
+hs-libraries: HSaeson-compat-0.3.1.0-0S7OUK4gqfF6axxSUneNAN
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -32,7 +32,8 @@ depends:
     scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
 haddock-html: /usr/share/doc/haskell-aeson-compat/html
